@@ -2,7 +2,7 @@ import abc
 import contextlib
 import socket
 from dataclasses import dataclass, replace
-from typing import Any, Callable, Dict, List, Optional, Tuple, TypeVar, Union
+from typing import Any, Callable, Dict, Generic, List, Optional, Tuple, TypeVar, Union
 
 import backoff
 
@@ -68,6 +68,26 @@ def map_many(mapper):
     return decorator
 
 
+def map_first(mapper):
+    """Map the first item in a series of results.
+
+    Examples:
+        >>> def noop(data):
+        ...     return data + 1
+
+        >>> mapper = map_first(noop)
+        >>> mapper([4, 6, 1, 0])
+        5
+    """
+
+    def decorator(response):
+        if response:
+            return mapper(response[0])
+        return None
+
+    return decorator
+
+
 def into_map(mapper, field):
     """Execute a given mapper for each item in a list, then map the result by some attribute.
 
@@ -141,18 +161,21 @@ def flatten(mapper):
     return decorator
 
 
-def noop_mapper(response):
+T = TypeVar("T")
+
+
+def noop_mapper(response: T) -> T:
     return response
 
 
 @dataclass
-class Request(metaclass=abc.ABCMeta):
-    def prepare(self) -> "PreparedRequest":
+class Request(Generic[T], metaclass=abc.ABCMeta):
+    def prepare(self) -> "PreparedRequest[T]":
         """Return a prepared request."""
 
 
 @dataclass
-class PreparedRequest(Request):
+class PreparedRequest(Request[T]):
     """The static definition of what it takes to make a request."""
 
     url: str
@@ -163,7 +186,7 @@ class PreparedRequest(Request):
     files: Optional[dict] = None
     params: Optional[dict] = None
     headers: Optional[dict] = None
-    response_mapper: Callable = noop_mapper
+    response_mapper: Callable[..., T] = noop_mapper
     map_with_request: bool = False
     is_paginated: bool = True
     extra: Optional[dict] = None
@@ -172,7 +195,7 @@ class PreparedRequest(Request):
     # A timeout of `0` is meant to indicate an explicit lack of a timeout i.e. infinite.
     timeout: Optional[int] = None
 
-    def prepare(self) -> "PreparedRequest":
+    def prepare(self) -> "PreparedRequest[T]":
         """Produce an identical `PreparedRequest` from the existing one.
 
         In particular, this can be useful to instantiate a specific request directly
